#!/bin/bash

RUN=""

# Destination directories
BINDIR="/usr/local/bin"
CONFDIR="/etc/namelookup-agi"
SBINDIR="/usr/local/sbin"
DATADIR="/usr/local/share/phonebook"
DOCDIR="/usr/local/share/doc/namelookup"
LOGDIR="/var/local/log/asterisk"
MAN1DIR="/usr/local/share/man/man1"
MAN5DIR="/usr/local/share/man/man5"
MAN8DIR="/usr/local/share/man/man8"
UTILDIR="/usr/local/share/phonebook/utils"
VARDIR="/var/local/lib/phonebook"
W3MDIR="/var/local/log/asterisk/.w3m"


# Copy and strip if newer
copy_bin() {
	# Original Path/File from tar
	ORIG="${1}"
	# Copy to this dir
	DIR="${2}"
	# Just the filename
	FILE=$( basename "${ORIG}" )
	if ! [ -f "${DIR}/${FILE}" ] || [ "${ORIG}" -nt "${DIR}/${FILE}" ]
	then
		cp "${ORIG}" "${DIR}/"
		strip "${DIR}/${FILE}"
	fi
}

# Copy and gzip man page if newer
copy_man() {
	# Original Path/File from tar
	ORIG="${1}"
	# Copy to this dir
	DIR="${2}"
	# Just the filename
	FILE=$( basename "${ORIG}" )
	if ! [ -f "${DIR}/${FILE}.gz" ] || [ "${ORIG}" -nt "${DIR}/${FILE}.gz" ]
	then
		cp "${ORIG}" "${DIR}/"
		gzip -f "${DIR}/${FILE}"
	fi
}


# Check UID
if [ "${UID}" -ne 0 ]
then
	echo "You need to be root to install."
	echo "Aborting install."
	exit 1
fi

# Install binaries
if [ ! -d "${BINDIR}" ]
then
	echo "Creating dir ${BINDIR}."
	mkdir -p "${BINDIR}"
fi
if [ ! -d "${SBINDIR}" ]
then
	echo "Creating dir ${SBINDIR}."
	mkdir -p "${SBINDIR}"
fi
echo "Copying binaries"
copy_bin agiblk2db "${BINDIR}"
copy_bin agiconf   "${BINDIR}"
copy_bin agidx2ph  "${BINDIR}"
copy_bin aginum2db "${BINDIR}"
copy_bin agiph2idx "${BINDIR}"
copy_bin csv2tsv   "${BINDIR}"
copy_bin namelookup "${BINDIR}"
copy_bin namelookup.agi "${SBINDIR}"

# Create conf dir
if [ ! -d "${CONFDIR}" ]
then
	echo "Creating dir ${CONFDIR}"
	mkdir -p "${CONFDIR}"
fi
# Install config files if they exist
if [ -f "agi-namelookup.conf " ]
then
	cp -u "agi-namelookup.conf " "${CONFDIR}/"
fi
if [ -f "agi-nameblock.db" ]
then
	cp -u "agi-nameblock.db" "${CONFDIR}/"
fi

# Install doc
if [ ! -d "${DOCDIR}" ]
then
	echo "Creating dir ${DOCDIR}."
	mkdir -p "${DOCDIR}"
fi
echo "Copying doc"
cp -ru doc/* "${DOCDIR}/"

# Install man pages
if [ ! -d "${MAN1DIR}" ]
then
	echo "Creating dir ${MAN1DIR}."
	mkdir -p "${MAN1DIR}"
fi
if [ ! -d "${MAN5DIR}" ]
then
	echo "Creating dir ${MAN5DIR}."
	mkdir -p "${MAN5DIR}"
fi
if [ ! -d "${MAN8DIR}" ]
then
	echo "Creating dir ${MAN8DIR}."
	mkdir -p "${MAN8DIR}"
fi
echo "Copying man pages."
copy_man man/agiconf.1   "${MAN1DIR}"
copy_man man/agiblk2db.1 "${MAN1DIR}"
copy_man man/agidx2ph.1  "${MAN1DIR}"
copy_man man/aginum2db.1 "${MAN1DIR}"
copy_man man/agiph2idx.1 "${MAN1DIR}"
copy_man man/csv2tsv.1   "${MAN1DIR}"
copy_man man/namelookup.agi.8 "${MAN8DIR}"
copy_man man/agi-nameblock.db.5 "${MAN5DIR}"
copy_man man/agi-namelookup.conf.5 "${MAN5DIR}"
copy_man man/confagi.conf.5 "${MAN5DIR}"

# Log dir
if [ -d "${LOGDIR}" ]
then
	echo "Dir ${LOGDIR} exists."
else
	echo "Creating dir ${LOGDIR}."
	mkdir -p "${LOGDIR}"
	chown asterisk:asterisk "${LOGDIR}"
fi
if [ -d "${W3MDIR}" ]
then
	echo "Dir ${W3MDIR} exists."
else
	echo "Creating dir ${W3MDIR}."
	mkdir -p "${W3MDIR}"
	# W3m might check permissions
	chmod 700 "${W3MDIR}"
	chmod g-s "${W3MDIR}"
	chown asterisk:asterisk "${W3MDIR}"
fi

# Data
if [ -d "${DATADIR}" ]
then
	echo "Dir ${DATADIR} exists."
else
	echo "Creating dir ${DATADIR}."
	mkdir -p "${DATADIR}"
fi
echo "Copying tsv files"
cp -u databases/*.tsv "${DATADIR}/"
if [ -d "${UTILDIR}" ]
then
	echo "Dir ${UTILDIR} exists."
else
	echo "Creating dir ${UTILDIR}"
	mkdir -p "${UTILDIR}"
fi
cp -u utils/*.sh "${UTILDIR}/"

# Var data
if [ -d "${VARDIR}" ]
then
	echo "Dir ${VARDIR} exists."
else
	echo "Creating dir ${VARDIR}."
	mkdir -p "${VARDIR}"
fi
echo "Copying db files"
if [ -f "areas.db" ]
then
	cp -u "areas.db" "${VARDIR}/"
elif [ -f "databases/areas.db" ]
then
	cp -u "databases/areas.db" "${VARDIR}/"
fi
if [ -f "regions.db" ]
then
	cp -u "regions.db" "${VARDIR}/"
elif [ -f "databases/regions.db" ]
then
	cp -u "databases/regions.db" "${VARDIR}/"
fi
if [ -f "numbers.db" ]
then
	cp -u "numbers.db" "${VARDIR}/"
	# A bit of privacy
	chmod 640 "${VARDIR}/numbers.db"
	chown root:asterisk "${VARDIR}/numbers.db"
fi

# Ncurses config tool
if [ -x "/usr/local/bin/agiconf" ]
then
	echo "Do you want agiconf to configure namelookup-agi now?"
	echo "Type 'y' <Enter> for yes."
	echo "Note: You can run agiconf later if you like."
	read RUN
else
	echo "agiconf not found"
	exit 1
fi

if [ "${RUN}" = "Y" ] || [ "${RUN}" = "y" ] || \
     [ "${RUN}" = "YES" ] || [ "${RUN}" = "Yes" ] || [ "${RUN}" = "yes" ]
then
	agiconf -c
	#agiconf -ac
fi

